@@ -11,21 +11,19 @@ import zipfile
 from logging.handlers import RotatingFileHandler
 from pathlib import Path, PurePath
 
-from FreeTAKServer.controllers.configuration.DataPackageServerConstants import DataPackageServerConstants
-from FreeTAKServer.controllers.configuration.SQLcommands import SQLcommands
-from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
+from FreeTAKServer.controllers.constants.DataPackageServerConstants import DataPackageServerConstants
+from FreeTAKServer.controllers.constants.SQLcommands import SQLcommands
+from FreeTAKServer.controllers.constants.LoggingConstants import LoggingConstants
 
 from flask import Flask, request, send_file
 from flask.logging import default_handler
 from werkzeug.datastructures import FileStorage
-log = logging.getLogger('werkzeug')
-log.setLevel(logging.ERROR)
 
 sql = SQLcommands()
 const = DataPackageServerConstants()
-log = LoggingConstants()
+log =LoggingConstants()
 
-app = Flask(__name__)  # create the Flask app
+app = Flask(__name__) #create the Flask app
 
 file_dir = os.path.dirname(os.path.realpath(__file__))
 dp_directory = PurePath(file_dir, const.DATAPACKAGEFOLDER)
@@ -50,30 +48,24 @@ console_handler.setLevel(logging.DEBUG)
 app.logger.addHandler(console_handler)
 app.logger.setLevel(logging.DEBUG)
 
-@app.route('/')
-def hello():
-    return 'hello world'
-
 @app.route("/Marti/vcm", methods=[const.GET])
 def get_all_video_links():
     # This is called when the user selects the Download button in the Videos window. It
     # expects an XML listing of all known feeds, so the user can pick and choose which ones
     # to store locally
     try:
-        db = sqlite3.connect(const.DATABASE)
-        cursor = db.cursor()
-        cursor.execute(sql.GETALLVIDEOS)
-        feeds = cursor.fetchall()
-        app.logger.info(f"Found {len(feeds)} video feeds in {const.DATABASE}")
-        if len(feeds) == 0:
-            return ("No video feeds found", 500)
-        all_feeds = ""
-        for feed in feeds:
-            # 'feed' is a tuple with one element, so we only append that
-            all_feeds += feed[0].decode("utf-8")
-        cursor.close()
-        db.close()
-        return f"<videoConnections>{all_feeds}</videoConnections>"
+        with sqlite3.connect(const.DATABASE) as db:
+            cursor = db.cursor()
+            cursor.execute(sql.GETALLVIDEOS)
+            feeds = cursor.fetchall()
+            app.logger.info(f"Found {len(feeds)} video feeds in {const.DATABASE}")
+            if len(feeds) == 0:
+                return ("No video feeds found", 500)
+            all_feeds = ""
+            for feed in feeds:
+                # 'feed' is a tuple with one element, so we only append that
+                all_feeds += feed[0].decode("utf-8")
+            return f"<videoConnections>{all_feeds}</videoConnections>"
     except:
         app.logger.error(traceback.format_exc())
         return "Error", 500
@@ -81,7 +73,7 @@ def get_all_video_links():
 
 @app.route("/Marti/vcm", methods=[const.POST])
 def insert_video_link():
-    db =  sqlite3.connect(const.DATABASE)
+    db = sqlite3.connect(const.DATABASE)
     cursor = db.cursor()
     try:
         xml_root = ET.fromstring(request.data.decode("utf-8"))
@@ -109,13 +101,11 @@ def insert_video_link():
                 (ET.tostring(xml_feed), protocol, alias, uid, address, port, rover_port,
                  ignore_klv, preferred_mac, path, buf, timeout, rtsp_reliable)
             )
-
         return "Okay", 200
     except:
         app.logger.error(traceback.format_exc())
         return "Error", 500
     finally:
-        cursor.close()
         db.commit()
         db.close()
 
@@ -132,45 +122,45 @@ def clientEndPoint():
 
 @app.route('/Marti/sync/missionupload', methods=[const.POST])
 def upload():
-    db = sqlite3.connect(const.DATABASE)
-    cursor = db.cursor()
-    file_hash = request.args.get('hash')
-    app.logger.info(f"Data Package hash = {str(file_hash)}")
-    letters = string.ascii_letters
-    uid = ''.join(random.choice(letters) for i in range(4))
-    uid = 'uid-' + str(uid)
-    filename = request.args.get('filename')
-    creatorUid = request.args.get('creatorUid')
-    file = request.files.getlist('assetfile')[0]
-    directory = Path(dp_directory, file_hash)
-    if not Path.exists(directory):
-        os.mkdir(directory)
-    file.save(os.path.join(directory, filename))
-    fileSize = Path(directory, filename).stat().st_size
-    callsign = str(
-        FlaskFunctions().getSubmissionUser(creatorUid))  # fetchone() gives a tuple, so only grab the first element
-    cursor.execute(sql.INSERTDPINFO, (uid, filename, file_hash, callsign, creatorUid, fileSize))
-    cursor.close()
-    db.commit()
-    db.close()
-    return IP + ':' + str(HTTPPORT) + "/Marti/api/sync/metadata/" + file_hash + "/tool"
+    with sqlite3.connect(const.DATABASE) as db:
+        cursor = db.cursor()
+        file_hash = request.args.get('hash')
+        app.logger.info(f"Data Package hash = {str(file_hash)}")
+        letters = string.ascii_letters
+        uid = ''.join(random.choice(letters) for i in range(4))
+        uid = 'uid-'+str(uid)
+        filename = request.args.get('filename')
+        creatorUid = request.args.get('creatorUid')
+        file = request.files.getlist('assetfile')[0]
+        directory = Path(dp_directory, file_hash)
+        if not Path.exists(directory):
+            os.mkdir(directory)
+        file.save(os.path.join(directory, filename))
+        fileSize = Path(directory, filename).stat().st_size
+        callsign = FlaskFunctions().getSubmissionUser(creatorUid) # fetchone() gives a tuple, so only grab the first element
+        cursor.execute(
+            sql.INSERTDPINFO,
+            (uid, filename, file_hash, callsign, creatorUid, fileSize)
+        )
+        cursor.close()
+        db.commit()
+    return IP+':'+const.HTTPPORT+"/Marti/api/sync/metadata/"+file_hash+"/tool"
 
 
 @app.route('/Marti/api/sync/metadata/<hash>/tool', methods=[const.PUT])
 def putDataPackageTool(hash):
     if request.data == b'private':
-        db = sqlite3.connect(const.DATABASE)
-        cursor = db.cursor()
-        cursor.execute("UPDATE DataPackages SET Privacy = 1 WHERE Hash = ?;", (hash,))
-        cursor.close()
-        db.commit()
-        db.close()
+        with sqlite3.connect(const.DATABASE) as db:
+            cursor = db.cursor()
+            cursor.execute("UPDATE DataPackages SET Privacy = 1 WHERE Hash = ?;", (hash,))
+            cursor.close()
+            db.commit()
     return "Okay", 200
 
 
 @app.route('/Marti/api/sync/metadata/<hash>/tool', methods=[const.GET])
 def getDataPackageTool(hash):
-    file_list = os.listdir(str(dp_directory) + '/' + str(hash))
+    file_list = os.listdir(str(dp_directory)+'/'+str(hash))
     path = PurePath(dp_directory, str(hash), file_list[0])
     app.logger.info(f"Sending data package from {str(path)}")
     return send_file(str(path))
@@ -187,9 +177,9 @@ def retrieveData():
 @app.route('/Marti/sync/content', methods=const.HTTPMETHODS)
 def specificPackage():
     hash = request.args.get('hash')
-    app.logger.debug(os.listdir(str(dp_directory) + '/' + str(hash)))
-    file_list = os.listdir(str(dp_directory) + '/' + str(hash))
-    app.logger.debug(const.DATAPACKAGEFOLDER + '\\' + hash + '\\' + file_list[0])
+    app.logger.debug(os.listdir(str(dp_directory)+'/'+str(hash)))
+    file_list = os.listdir(str(dp_directory)+'/'+str(hash))
+    app.logger.debug(const.DATAPACKAGEFOLDER+'\\'+hash+'\\'+file_list[0])
     path = PurePath(dp_directory, str(hash), file_list[0])
     app.logger.debug(str(path))
     return send_file(str(path))
@@ -205,94 +195,86 @@ def checkPresent():
     hash = request.args.get('hash')
     if FlaskFunctions().hashIsPresent(hash):
         app.logger.info(f"Data package with hash {hash} exists")
-        return IP + ':' + str(HTTPPORT) + "/Marti/api/sync/metadata/" + hash + "/tool"
+        return IP+':'+const.HTTPPORT+"/Marti/api/sync/metadata/"+hash+"/tool"
     else:
         app.logger.info(f"Data package with hash {hash} does not exist")
         return '404', 404
 
-@app.route('/')
-def home():
-    return 'data package service is up, good job.'
 class FlaskFunctions:
 
     def __init__(self):
         self.callsigns = []
 
     def hashIsPresent(self, hash):
-        db = sqlite3.connect(const.DATABASE)
-        cursor = db.cursor()
-        cursor.execute(sql.ROWBYHASH, (hash,))
-        data = cursor.fetchall()
-        cursor.close()
-        db.close()
-        return len(data) > 0
+        with sqlite3.connect(const.DATABASE) as db:
+            cursor = db.cursor()
+            cursor.execute(sql.ROWBYHASH, (hash,))
+            data = cursor.fetchall()
+            cursor.close()
+            return len(data) > 0
 
+    def SubmissionUsersPipe(self):
+        while PIPE.poll():
+            callsign = PIPE.recv()
+            if callsign[0] == 'add':
+                self.callsigns.append(callsign)
+            elif callsign[0] == 'remove':
+                self.callsigns.remove(callsign)
+            else:
+                pass
     def getSubmissionUser(self, UID):
-        db = sqlite3.connect(const.DATABASE)
-        cursor = db.cursor()
-        cursor.execute(sql.RETRIEVECALLSIGNFROMUID, (UID,))
-        callsign = cursor.fetchone()
-        cursor.close()
-        db.close()
-        return callsign
+        self.SubmissionUsersPipe()
+        for user in self.callsigns:
+            if user[1] == UID:
+                return user[2]
+            else:
+                pass
 
     def getAllPackages(self):
-        db = sqlite3.connect(const.DATABASE)
-        cursor = db.cursor()
-        cursor.execute(sql.SELECTALLDP)
-        data = cursor.fetchall()
-        cursor.close()
-        db.close()
-        package_dict = {
-            "resultCount": len(data),
-            "results": []
-        }
-        for i in data:
-            package_dict["results"].append({
-                "UID": i[1],
-                "Name": i[2],
-                "Hash": i[3],
-                "PrimaryKey": i[0],
-                "SubmissionDateTime": i[4],
-                "SubmissionUser": i[5],
-                "CreatorUid": i[6],
-                "Keywords": i[7],
-                "MIMEType": i[8],
-                "Size": i[9]
-            })
-        return package_dict
+        with sqlite3.connect(const.DATABASE) as db:
+            cursor = db.cursor()
+            cursor.execute(sql.SELECTALLDP)
+            data = cursor.fetchall()
+            cursor.close()
+            package_dict = {
+                "resultCount": len(data),
+                "results": []
+            }
+            for i in data:
+                package_dict["results"].append({
+                    "UID": i[1],
+                    "Name": i[2],
+                    "Hash": i[3],
+                    "PrimaryKey": i[0],
+                    "SubmissionDateTime": i[4],
+                    "SubmissionUser": i[5],
+                    "CreatorUid": i[6],
+                    "Keywords": i[7],
+                    "MIMEType": i[8],
+                    "Size": i[9]
+                })
+            return package_dict
 
-    def startup(self, ip, port):
-        try:
-            global IP, HTTPPORT
-            IP = ip
-            HTTPPORT = port
+    def startup(self, ip, port, pipe):
+        global IP, HTTPPORT, PIPE
+        PIPE = pipe
+        IP = ip
+        HTTPPORT = port
             # Make sure the data package directory exists
-            if not Path(dp_directory).exists():
-                app.logger.info(f"Creating directory at {str(dp_directory)}")
-                os.makedirs(str(dp_directory))
-            # Create the relevant database tables
-            db = sqlite3.connect(const.DATABASE)
+        if not Path(dp_directory).exists():
+            app.logger.info(f"Creating directory at {str(dp_directory)}")
+            os.makedirs(str(dp_directory))
+
+        # Create the relevant database tables
+        with sqlite3.connect(const.DATABASE) as db:
             cursor = db.cursor()
             cursor.execute(sql.CREATEDPTABLE)
             cursor.execute(sql.CREATEVIDEOTABLE)
-            cursor.execute(sql.CREATEUSERTABLE)
             cursor.close()
             db.commit()
-            db.close()
-            print(const.IP)
-            print(HTTPPORT)
-            app.run(host= ip, port=HTTPPORT, debug=const.HTTPDEBUG)
-        except Exception as e:
-            logger.error('there has been an exception in Data Package service startup ' + str(e))
-            return -1
 
-    def stop(self):
-        func = request.environ.get('werkzeug.server.shutdown')
-        if func is None:
-            raise RuntimeError('Not running with the Werkzeug Server')
-        func()
+        app.run(host=IP, port=HTTPPORT, debug=const.HTTPDEBUG)
 
 if __name__ == "__main__":
     pass
-
+    
