@@ -1,8 +1,8 @@
 from FreeTAKServer.controllers.model.SendInvalidCoT import SendInvalidCoT
 class SendInvalidCoTController:
     def __init__(self, RawCOT):
-        self.SendInvalidCoT = SendInvalidCoT()
-        self.SendInvalidCoT.clientInformation = RawCOT.clientInformation
+        self.m_SendInvalidCoT = SendInvalidCoT()
+        self.m_SendInvalidCoT.clientInformation = RawCOT.clientInformation
 
     def getObject(self):
-        return self.SendInvalidCoT
\ No newline at end of file
+        return self.m_SendInvalidCoT
\ No newline at end of file
